@@ -13,6 +13,9 @@ __all__ = (
 )
 
 
+pytest_plugins = ["pytester"]
+
+
 @pytest.fixture
 def http_request_factory():
     """
@@ -47,3 +50,13 @@ def markdown_with_pytest_mark():
 ```python name=test_db
 from django.db import models
 ```"""
+
+
+@pytest.fixture
+def pytester_subprocess(pytester):
+    """
+    Wrapper that forces subprocess mode to avoid deprecation warning conflicts
+    when the plugin uses the old `path` argument signature.
+    """
+    pytester.runpytest = pytester.runpytest_subprocess
+    return pytester
